@@ -18,6 +18,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+import io
 import pytest
 import numpy as np
 
@@ -26,6 +27,65 @@ import pyecvl.ecvl as ecvl_py
 tensor = pytest.importorskip("pyeddl.tensor")
 
 
+IMAGES = [f"foo_{i}.png" for i in range(3)]
+GROUND_TRUTHS = [f"foo_{i}_gt.png" for i in range(3)]
+
+SEG_DATASET = f"""\
+name: Foo
+description: FooDesc
+images:
+- location: {IMAGES[0]}
+  label: {GROUND_TRUTHS[0]}
+- location: {IMAGES[1]}
+  label: {GROUND_TRUTHS[1]}
+- location: {IMAGES[2]}
+  label: {GROUND_TRUTHS[2]}
+split:
+  training:
+  - 0
+  - 1
+  test:
+  - 2
+"""
+
+CLS_DATASET = f"""\
+name: Foo
+description: FooDesc
+classes:
+- '0'
+- '1'
+images:
+- location: {IMAGES[0]}
+  label: 0
+- location: {IMAGES[1]}
+  label: 1
+- location: {IMAGES[2]}
+  label: 1
+split:
+  training:
+  - 0
+  - 1
+  test:
+  - 2
+"""
+
+
+def _build_dataset(dir_path, type_="seg"):
+    fn = str(dir_path / "foo.yml")
+    with io.open(fn, "wt") as f:
+        f.write(SEG_DATASET if type_ == "seg" else CLS_DATASET)
+    for name in IMAGES:
+        a = np.random.randint(0, 255, [20, 40, 3], dtype=np.uint8)
+        img = ecvl_py.Image.fromarray(a, "xyc", ecvl_py.ColorType.RGB)
+        ecvl_py.ImWrite(str(dir_path / name), img)
+    if type_ == "seg":
+        for name in GROUND_TRUTHS:
+            a = np.random.randint(0, 255, [20, 40, 1], dtype=np.uint8)
+            img = ecvl_py.Image.fromarray(a, "xyc", ecvl_py.ColorType.GRAY)
+            ecvl_py.ImWrite(str(dir_path / name), img)
+    return fn
+
+
 def _img_fromarray(ecvl, array, channels, colortype, spacings=None):
     if spacings is None:
         spacings = []
@@ -52,58 +112,30 @@ def test_DatasetAugmentations(ecvl):
     assert ecvl.DatasetAugmentations([]).IsEmpty()
 
 
-@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
-def test_LabelClass(ecvl):
-    lc = ecvl.LabelClass()
-    lc.label = [0, 1, 3, 5]
-    t = tensor.Tensor.zeros([4, 6])
-    lc.ToTensorPlane(t, 2)
-    a = t.getdata()
-    for j in lc.label:
-        assert a[2, j] == 1.0
-
-
-@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
-def test_LabelImage(ecvl):
-    a = np.arange(24).reshape((3, 4, 2)).astype(np.uint8)
-    a_img = _img_fromarray(ecvl, a, "xyc", ecvl.ColorType.BGR)
-    a_tensor = ecvl.ImageToTensor(a_img)
-    assert a_tensor.shape == [2, 4, 3]
-    t = tensor.Tensor.zeros([4, 4, 3])
-    li = ecvl.LabelImage()
-    li.gt = a_img
-    li.ToTensorPlane(t, 1)
-    t_arr = t.getdata()
-    assert np.array_equal(t_arr[2:], a_tensor.getdata())
-
-
 @pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
 def test_ProducersConsumerQueue(ecvl):
     s = ecvl.Sample()
     s.location_, s.size_ = ["foo.png"], [400, 300]
-    img = ecvl.Image([3, 4, 5], ecvl.DataType.uint8, "xyc", ecvl.ColorType.RGB)
-    lc = ecvl.LabelClass()
-    lc.label = [0, 2]
+    img_tensor = tensor.Tensor([5, 4, 3])
+    gt_tensor = tensor.Tensor([5, 4, 3])
     q = ecvl.ProducersConsumerQueue(5)
     assert not q.IsFull()
     assert q.IsEmpty()
     assert q.Length() == 0
-    q.Push(s, img, lc)
+    q.Push(s, img_tensor, gt_tensor)
     assert not q.IsFull()
     assert not q.IsEmpty()
     assert q.Length() == 1
-    s_, img_, lc_ = q.Pop()
+    s_, img_tensor_, gt_tensor_ = q.Pop()
     assert not q.IsFull()
     assert q.IsEmpty()
     assert q.Length() == 0
     assert s_.location_ == s.location_
     assert s_.size_ == s.size_
-    assert img_.dims_ == img.dims_
-    assert img_.elemtype_ == img.elemtype_
-    assert img_.channels_ == img.channels_
-    assert img_.colortype_ == img.colortype_
+    assert img_tensor_ is img_tensor
+    assert gt_tensor_ is gt_tensor
     q.SetSize(1, -1)
-    q.Push(s, img, lc)
+    q.Push(s, img_tensor, gt_tensor)
     assert q.IsFull()
     q.SetSize(8)
     assert not q.IsFull()
@@ -185,3 +217,48 @@ def test_TensorToView(ecvl):
     t = tensor.Tensor(shape)
     view = ecvl.TensorToView(t)
     assert view.dims_ == [shape[3], shape[2], shape[0] * shape[1]]
+
+
+@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
+def test_DLDataset_seg(ecvl, tmp_path):
+    augs = ecvl.DatasetAugmentations([ecvl.AugFlip(0.5)])
+    fn = _build_dataset(tmp_path, "seg")
+    batch_size = 1
+    d = ecvl.DLDataset(fn, batch_size, augs)
+    assert d.n_channels_ == 3
+    assert d.n_channels_gt_ == 1
+    d.ResetBatch()
+    d.ResetBatch(0)
+    d.ResetBatch(0, True)
+    d.ResetAllBatches()
+    d.ResetAllBatches(True)
+    x = tensor.Tensor([batch_size, d.n_channels_, d.resize_dims_[0], d.resize_dims_[1]])
+    d.LoadBatch(x)
+    ecvl.DLDataset.SetSplitSeed(12345)
+    d.ResetBatch()
+    d.SetWorkers(1)
+    d.Start()
+    assert len(d.GetBatch()) == 3
+    d.Stop()
+    d.SetNumChannels(1)
+    d.SetNumChannels(1, 1)
+    assert d.GetQueueSize() < len(d.samples_)
+    d.SetAugmentations(ecvl.DatasetAugmentations([ecvl.AugFlip(0.9)]))
+    assert d.GetNumBatches() == d.GetNumBatches(ecvl.SplitType.training) == 2
+    assert d.GetNumBatches(ecvl.SplitType.test) == 1
+
+
+@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
+def test_DLDataset_cls(ecvl, tmp_path):
+    augs = ecvl.DatasetAugmentations([ecvl.AugFlip(0.5)])
+    fn = _build_dataset(tmp_path, "cls")
+    batch_size = 2
+    d = ecvl.DLDataset(fn, batch_size, augs)
+    assert d.n_channels_ == 3
+    x = tensor.Tensor([batch_size, d.n_channels_, d.resize_dims_[0], d.resize_dims_[1]])
+    y = tensor.Tensor([batch_size, len(d.classes_)])
+    d.LoadBatch(x, y)
+    t = d.ToTensorPlane(d.samples_[0].label_)
+    assert np.allclose(np.array(t), [1, 0])
+    t = d.ToTensorPlane(d.samples_[1].label_)
+    assert np.allclose(np.array(t), [0, 1])
